@@ -1,15 +1,18 @@
 from abc import (
     ABCMeta,
 )
+from pydantic.fields import (
+    Field,
+)
 from typing import (
     TYPE_CHECKING,
 )
 
-from pydantic.fields import (
-    Field,
-)
 from uploader_client.const import (
     DEFAULT_DATAMART_URL,
+    DEFAULT_MAX_CONNECTIONS,
+    DEFAULT_MAX_KEEPALIVE_CONNECTIONS,
+    DEFAULT_POOL_TIMEOUT,
     DEFAULT_REQUEST_RETRIES,
     DEFAULT_REQUEST_TIMEOUT,
     DEFAULT_RETRY_FACTOR,
@@ -61,6 +64,21 @@ class Config(AbstractConfig):
         default=DEFAULT_REQUEST_TIMEOUT,
     )
 
+    max_connections: int = Field(
+        title='Максимальное количество одновременных соединений',
+        default=DEFAULT_MAX_CONNECTIONS,
+    )
+
+    max_keepalive_connections: int = Field(
+        title='Максимальное количество keep-alive соединений в пуле',
+        default=DEFAULT_MAX_KEEPALIVE_CONNECTIONS,
+    )
+
+    pool_timeout: float = Field(
+        title='Таймаут ожидания свободного соединения из пула, сек',
+        default=DEFAULT_POOL_TIMEOUT,
+    )
+
     interface: str = 'uploader_client.interfaces.rest.OpenAPIInterface'
 
     logger: str = 'uploader_client.logging.db.Logger'
